*********************************************
:mod:`mopidy.audio.mixers.auto` -- Auto mixer
*********************************************

.. automodule:: mopidy.audio.mixers.auto
    :synopsis: Mixer element which automatically selects the real mixer to use
